###

###

###

###

###

    	monetary
    		# Mongo
    		# yurt

    		http://192.168.0.100:39000

    		node_data
    			/habitat/venues/stages/goodest/adventures/monetary/__monetary_1

    		saves
    			ls "/habitat/venues/stages/goodest/[saves]"

    		saving
    			goodest_1 adventures monetary saves export --version 4

    		loading
    			goodest_1 adventures monetary saves import --version 8 --drop